@@ -2,7 +2,7 @@ import sys
 import rich_click as click
 import json
 import yaml
-import pandas
+import pandas as pd
 import tabulate
 import logging
 from pyats.topology import Testbed, Device
@@ -14,8 +14,6 @@ from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 from fpdf import FPDF
 
-
-
 class GetJson():
     def __init__(self, hostname, os, username, password, command, filetype):
         self.hostname = hostname
@@ -47,6 +45,8 @@ class GetJson():
             self.pdf_file(parsed_json)
         elif self.filetype == 'markdown':
             self.markdown_file(parsed_json)
+        elif self.filetype == 'csv':
+            self.csv_file(parsed_json)
     
     def json_file(self, parsed_json):
         with open(f'{self.hostname} {self.command}.json', 'w') as f:
@@ -90,11 +90,17 @@ class GetJson():
         click.secho(f"PDF file created at { sys.path[0] }/{self.hostname} {self.command}.pdf", fg='green')
 
     def markdown_file(self, parsed_json):
-        df = pandas.json_normalize(json.loads(parsed_json),max_level=2)
+        df = pd.json_normalize(json.loads(parsed_json),max_level=2)
         markdown_table = df.to_markdown(index='false')
         with open(f'{self.hostname} {self.command}.md', 'w') as f:
             f.write(markdown_table)
         click.secho(f"Markdown file created at { sys.path[0] }/{self.hostname} {self.command}.md", fg='green')
+
+    def csv_file(self, parsed_json, expand_all=False):
+        df = pd.json_normalize(json.loads(parsed_json))
+        df.to_csv(f'{self.hostname} {self.command}.csv', index=False)
+        click.secho(f"CSV file created at { sys.path[0] }/{self.hostname} {self.command}.csv", fg='green')
+
     # Create Testbed
     def connect_device(self):
         try:
@@ -160,7 +166,7 @@ class GetJson():
 @click.option('--username', prompt='Username', help='Username', required=True)
 @click.option('--password', prompt=True, hide_input=True, help="User Password", required=True)
 @click.option('--command', prompt='Command', help='A valid pyATS Learn Function (i.e. ospf) or valid CLI Show Command (i.e. "show ip interface brief")', required=True)
-@click.option('--filetype', prompt='Filetype', type=click.Choice(['none','json','yaml','html','datatable','markdown','pdf'], case_sensitive=True), help='Filetype to output captured network state to', required=False, default='none')
+@click.option('--filetype', prompt='Filetype', type=click.Choice(['none','json','yaml','html','datatable','markdown','pdf','csv'], case_sensitive=True), help='Filetype to output captured network state to', required=False, default='none')
 def cli(hostname, os, username, password, command, filetype):
     invoke_class = GetJson(hostname, os, username, password, command, filetype)
     invoke_class.print_json()
